@@ -2,13 +2,13 @@ import json
 import warnings
 from glob import iglob
 from typing import List, Any, Callable
-from dh_client.exceptions import FailedToEmmitMpc
 
 import requests
 from datahub.emitter.mcp import MetadataChangeProposalWrapper, DictWrapper
 from datahub.metadata.schema_classes import ChangeTypeClass
 
 from dh_client.client import RestClient
+from dh_client.exceptions import FailedToEmmitMpc
 from dh_client.exceptions import NotSupportedYet
 
 __all__ = ["datasets", "glossary_terms", "owners", "tags", "users", "dashboards"]
@@ -36,13 +36,14 @@ class Entity:
 
         for mpc_ in mpc or []:
             if mpc_.pop("use_graphql", use_graphql):
-                print(self.emmiter.graphql_headers, self.emmiter.graphql_url)
                 r = requests.post(
                     self.emmiter.graphql_url,
                     headers=self.emmiter.graphql_headers,
                     json=mpc_,
                 )
-                r.raise_for_status()
+                j = r.json()
+                if "errors" in j:
+                    raise ValueError(j)
             else:
                 try:
                     self.emmiter.emit(
