@@ -169,9 +169,7 @@ class Dataset(Entity):
             "variables": {
                 "input": {
                     "tagUrn": builder.make_tag_urn(tag),
-                    "resourceUrn": self.create_resource_urn(
-                        dataset_urn, platform, env
-                    ),
+                    "resourceUrn": self.create_resource_urn(dataset_urn, platform, env),
                     "subResourceType": None,
                 }
             },
@@ -197,9 +195,7 @@ class Dataset(Entity):
             "variables": {
                 "input": {
                     "tagUrn": builder.make_tag_urn(tag),
-                    "resourceUrn": self.create_resource_urn(
-                        dataset_urn, platform, env
-                    ),
+                    "resourceUrn": self.create_resource_urn(dataset_urn, platform, env),
                     "subResourceType": None,
                 }
             },
@@ -211,7 +207,7 @@ class Dataset(Entity):
         self,
         dataset_urn: str,
         label: str,
-            link: str,
+        link: str,
         platform: str = "bigquery",
         env: str = "DEV",
     ) -> None:
@@ -234,9 +230,7 @@ class Dataset(Entity):
                 "input": {
                     "linkUrl": link,
                     "label": label,
-                    "resourceUrn": self.create_resource_urn(
-                        dataset_urn, platform, env
-                    ),
+                    "resourceUrn": self.create_resource_urn(dataset_urn, platform, env),
                     "subResourceType": None,
                 }
             },
